package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcWpyrwwclMapper;
import com.ruoyi.zongzhi.domain.TcWpyrwwcl;
import com.ruoyi.zongzhi.service.ITcWpyrwwclService;

/**
 * 网评员任务完成率心Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
@Service
public class TcWpyrwwclServiceImpl implements ITcWpyrwwclService 
{
    @Autowired
    private TcWpyrwwclMapper tcWpyrwwclMapper;

    /**
     * 查询网评员任务完成率心
     * 
     * @param id 网评员任务完成率心主键
     * @return 网评员任务完成率心
     */
    @Override
    public TcWpyrwwcl selectTcWpyrwwclById(Long id)
    {
        return tcWpyrwwclMapper.selectTcWpyrwwclById(id);
    }

    /**
     * 查询网评员任务完成率心列表
     * 
     * @param tcWpyrwwcl 网评员任务完成率心
     * @return 网评员任务完成率心
     */
    @Override
    public List<TcWpyrwwcl> selectTcWpyrwwclList(TcWpyrwwcl tcWpyrwwcl)
    {
        return tcWpyrwwclMapper.selectTcWpyrwwclList(tcWpyrwwcl);
    }

    /**
     * 新增网评员任务完成率心
     * 
     * @param tcWpyrwwcl 网评员任务完成率心
     * @return 结果
     */
    @Override
    public int insertTcWpyrwwcl(TcWpyrwwcl tcWpyrwwcl)
    {
        return tcWpyrwwclMapper.insertTcWpyrwwcl(tcWpyrwwcl);
    }

    /**
     * 修改网评员任务完成率心
     * 
     * @param tcWpyrwwcl 网评员任务完成率心
     * @return 结果
     */
    @Override
    public int updateTcWpyrwwcl(TcWpyrwwcl tcWpyrwwcl)
    {
        return tcWpyrwwclMapper.updateTcWpyrwwcl(tcWpyrwwcl);
    }

    /**
     * 批量删除网评员任务完成率心
     * 
     * @param ids 需要删除的网评员任务完成率心主键
     * @return 结果
     */
    @Override
    public int deleteTcWpyrwwclByIds(Long[] ids)
    {
        return tcWpyrwwclMapper.deleteTcWpyrwwclByIds(ids);
    }

    /**
     * 删除网评员任务完成率心信息
     * 
     * @param id 网评员任务完成率心主键
     * @return 结果
     */
    @Override
    public int deleteTcWpyrwwclById(Long id)
    {
        return tcWpyrwwclMapper.deleteTcWpyrwwclById(id);
    }
}
